@@ -1,6 +1,6 @@
 #######################################################################
-# $Date: 2007-05-31 17:58:27 -0700 (Thu, 31 May 2007) $
-# $Revision: 34 $
+# $Date: 2007-06-01 02:58:25 -0700 (Fri, 01 Jun 2007) $
+# $Revision: 48 $
 # $Author: david.romano $
 # ex: set ts=8 sw=4 et
 #########################################################################
@@ -10,21 +10,29 @@ use warnings;
 use strict;
 use Carp;
 
-use version; our $VERSION = qv('0.1.6');
+use version; our $VERSION = qv('0.2.0');
 
-use Moose;
-extends 'Moose::Object';
+sub base { return shift->{'base'}; }
 
-has 'base' => ( is => 'ro', isa => 'WWW::Facebook::API::Base' );
+sub new {
+    my ( $self, %args ) = @_;
+    my $class = ref $self || $self;
+    $self = bless \%args, $class;
 
-sub add_tag         { shift->base->call( 'photos.addTag', @_ )        }
-sub create_album    { shift->base->call( 'photos.createAlbum', @_ )   }
-sub get             { shift->base->call( 'photos.get', @_ )           }
-sub get_albums      { shift->base->call( 'photos.getAlbums', @_ )     }
-sub get_tags        { shift->base->call( 'photos.getTags', @_ )       }
-sub upload          { shift->base->call( 'photos.upload', @_ )        }
+    delete $self->{$_} for grep !/base/, keys %$self;
+    $self->$_ for keys %$self;
 
-1; # Magic true value required at end of module
+    return $self;
+}
+
+sub add_tag      { shift->base->call( 'photos.addTag',      @_ ) }
+sub create_album { shift->base->call( 'photos.createAlbum', @_ ) }
+sub get          { shift->base->call( 'photos.get',         @_ ) }
+sub get_albums   { shift->base->call( 'photos.getAlbums',   @_ ) }
+sub get_tags     { shift->base->call( 'photos.getTags',     @_ ) }
+sub upload       { shift->base->call( 'photos.upload',      @_ ) }
+
+1;    # Magic true value required at end of module
 __END__
 
 =head1 NAME
@@ -34,7 +42,7 @@ WWW::Facebook::API::Photos - Photos methods for Client
 
 =head1 VERSION
 
-This document describes WWW::Facebook::API::Photos version 0.1.6
+This document describes WWW::Facebook::API::Photos version 0.2.0
 
 
 =head1 SYNOPSIS
@@ -49,6 +57,10 @@ Methods for accessing photos with L<WWW::Facebook::API>
 
 =over
 
+=item new
+
+Returns a new instance of this class.
+
 =item base
 
 The L<WWW::Facebook::API::Base> object to use to make calls to
@@ -93,8 +105,7 @@ environment variables.
 
 =head1 DEPENDENCIES
 
-L<Moose>
-L<WWW::Facebook::API::Base>
+See L<WWW::Facebook::API>
 
 
 =head1 INCOMPATIBILITIES
