@@ -1,6 +1,6 @@
 #######################################################################
-# $Date: 2007-05-31 17:58:27 -0700 (Thu, 31 May 2007) $
-# $Revision: 34 $
+# $Date: 2007-06-01 02:58:25 -0700 (Fri, 01 Jun 2007) $
+# $Revision: 48 $
 # $Author: david.romano $
 # ex: set ts=8 sw=4 et
 #########################################################################
@@ -10,34 +10,25 @@ use warnings;
 use strict;
 use Carp;
 
-use version; our $VERSION = qv('0.1.6');
+use version; our $VERSION = qv('0.2.0');
 
-use Moose;
-extends 'Moose::Object';
+sub base { return shift->{'base'}; }
 
-has 'base' => ( is => 'ro', isa => 'WWW::Facebook::API::Base' );
+sub new {
+    my ( $self, %args ) = @_;
+    my $class = ref $self || $self;
+    $self = bless \%args, $class;
 
-sub get_info {
-    my $self = shift;
-    my $value = $self->base->call( 'users.getInfo', @_ );
+    delete $self->{$_} for grep !/base/, keys %$self;
+    for ( keys %$self ) { $self->$_ }
 
-    return $value if $self->base->format eq 'JSON';
-
-    # remove erraneous hash refs in quotes
-    my $node = $self->base->simple
-        ? $value
-        : $value->{users_getInfo_response}->[0]->{user};
-    for ( @$node ) {
-        next unless $_->{'quotes'};
-        $_->{'quotes'}->[0] = q{} if ref $_->{'quotes'}->[0];
-    }
-
-    return $value;
+    return $self;
 }
 
+sub get_info           { shift->base->call( 'users.getInfo',         @_ ); }
 sub get_logged_in_user { shift->base->call( 'users.getLoggedInUser', @_ ) }
 
-1; # Magic true value required at end of module
+1;    # Magic true value required at end of module
 __END__
 
 =head1 NAME
@@ -47,12 +38,12 @@ WWW::Facebook::API::Users - Users methods for Client
 
 =head1 VERSION
 
-This document describes WWW::Facebook::API::Users version 0.1.6
+This document describes WWW::Facebook::API::Users version 0.2.0
 
 
 =head1 SYNOPSIS
 
-    use WWW::Facebook::API::Users;
+    use WWW::Facebook::API;
 
 
 =head1 DESCRIPTION
@@ -64,6 +55,10 @@ Methods for accessing users with L<WWW::Facebook::API>
 
 =over
 
+=item new
+
+Returns a new instance of this class.
+
 =item base
 
 The L<WWW::Facebook::API::Base> object to use to make calls to
@@ -94,8 +89,7 @@ environment variables.
 
 =head1 DEPENDENCIES
 
-L<Moose>
-L<WWW::Facebook::API::Base>
+See L<WWW::Facebook::API>
 
 
 =head1 INCOMPATIBILITIES
